@@ -16,13 +16,13 @@ use File::Glob qw(:case);
 # complain if it can't find them)
 
 @IGNORABLE = qw(
-    .cvsignore .dualLivedDiffConfig .gitignore
-    ANNOUNCE Announce Artistic AUTHORS BENCHMARK BUGS Build.PL
-    CHANGELOG ChangeLog Changelog CHANGES Changes CONTRIBUTING COPYING Copying
-    cpanfile CREDITS dist.ini GOALS HISTORY INSTALL INSTALL.SKIP LICENSE
-    Makefile.PL MANIFEST MANIFEST.SKIP META.json META.yml MYMETA.json
-    MYMETA.yml NEW NOTES perlcritic.rc ppport.h README README.PATCHING
-    SIGNATURE THANKS TODO Todo VERSION WHATSNEW .perlcriticrc.perltidyrc
+    .cvsignore .dualLivedDiffConfig .gitignore .perlcriticrc .perltidyrc
+    .travis.yml ANNOUNCE Announce Artistic AUTHORS BENCHMARK BUGS Build.PL
+    CHANGELOG ChangeLog Changelog CHANGES Changes CONTRIBUTING CONTRIBUTING.mkdn
+    COPYING Copying cpanfile CREDITS dist.ini GOALS HISTORY INSTALL INSTALL.SKIP
+    LICENSE Makefile.PL MANIFEST MANIFEST.SKIP META.json META.yml MYMETA.json
+    MYMETA.yml NEW NEWS NOTES perlcritic.rc ppport.h README README.PATCHING
+    SIGNATURE THANKS TODO Todo VERSION WHATSNEW
 );
 
 # Each entry in the  %Modules hash roughly represents a distribution,
@@ -119,7 +119,7 @@ use File::Glob qw(:case);
 %Modules = (
 
     'Archive::Tar' => {
-        'DISTRIBUTION' => 'BINGOS/Archive-Tar-2.00.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Archive-Tar-2.04.tar.gz',
         'FILES'        => q[cpan/Archive-Tar],
         'BUGS'         => 'bug-archive-tar@rt.cpan.org',
         'EXCLUDED'     => [
@@ -133,7 +133,7 @@ use File::Glob qw(:case);
     },
 
     'autodie' => {
-        'DISTRIBUTION' => 'PJF/autodie-2.25.tar.gz',
+        'DISTRIBUTION' => 'NTHYKIER/autodie-2.26.tar.gz',
         'FILES'        => q[cpan/autodie],
         'EXCLUDED'     => [
             qr{benchmarks},
@@ -156,10 +156,6 @@ use File::Glob qw(:case);
                 t/system.t
                 )
         ],
-        'CUSTOMIZED'   => [
-            # Waiting to be merged upstream: see CPAN RT#87237
-            qw(	t/utf8_open.t ),
-        ],
     },
 
     'AutoLoader' => {
@@ -175,7 +171,7 @@ use File::Glob qw(:case);
     },
 
     'B::Debug' => {
-        'DISTRIBUTION' => 'RURBAN/B-Debug-1.21.tar.gz',
+        'DISTRIBUTION' => 'RURBAN/B-Debug-1.23.tar.gz',
         'FILES'        => q[cpan/B-Debug],
         'EXCLUDED'     => ['t/pod.t'],
     },
@@ -202,7 +198,7 @@ use File::Glob qw(:case);
     },
 
     'Compress::Raw::Bzip2' => {
-        'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.064.tar.gz',
+        'DISTRIBUTION' => 'PMQS/Compress-Raw-Bzip2-2.068.tar.gz',
         'FILES'        => q[cpan/Compress-Raw-Bzip2],
         'EXCLUDED'     => [
             qr{^t/Test/},
@@ -211,7 +207,7 @@ use File::Glob qw(:case);
     },
 
     'Compress::Raw::Zlib' => {
-        'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.065.tar.gz',
+        'DISTRIBUTION' => 'PMQS/Compress-Raw-Zlib-2.068.tar.gz',
 
         'FILES'    => q[cpan/Compress-Raw-Zlib],
         'EXCLUDED' => [
@@ -224,7 +220,7 @@ use File::Glob qw(:case);
     },
 
     'Config::Perl::V' => {
-        'DISTRIBUTION' => 'HMBRAND/Config-Perl-V-0.22.tgz',
+        'DISTRIBUTION' => 'HMBRAND/Config-Perl-V-0.23.tgz',
         'FILES'        => q[cpan/Config-Perl-V],
         'EXCLUDED'     => [qw(
 		examples/show-v.pl
@@ -281,12 +277,24 @@ use File::Glob qw(:case);
                 t/yaml_code.yml
                 ),
         ],
+        # Waiting to be merged upstream: see pull request #83
+        'CUSTOMIZED'   => [
+            qw( lib/CPAN/Author.pm
+                lib/CPAN/CacheMgr.pm
+                lib/CPAN/FTP.pm
+                lib/CPAN/HTTP/Client.pm
+                lib/CPAN/HandleConfig.pm
+                lib/CPAN/Index.pm
+                lib/CPAN/LWP/UserAgent.pm
+                lib/CPAN/Mirrors.pm
+                ),
+        ],
     },
 
     # Note: When updating CPAN-Meta the META.* files will need to be regenerated
     # perl -Icpan/CPAN-Meta/lib Porting/makemeta
     'CPAN::Meta' => {
-        'DISTRIBUTION' => 'DAGOLDEN/CPAN-Meta-2.142060.tar.gz',
+        'DISTRIBUTION' => 'DAGOLDEN/CPAN-Meta-2.143240.tar.gz',
         'FILES'        => q[cpan/CPAN-Meta],
         'EXCLUDED'     => [
             qw[t/00-report-prereqs.t],
@@ -298,13 +306,13 @@ use File::Glob qw(:case);
     },
 
     'CPAN::Meta::Requirements' => {
-        'DISTRIBUTION' => 'DAGOLDEN/CPAN-Meta-Requirements-2.126.tar.gz',
+        'DISTRIBUTION' => 'DAGOLDEN/CPAN-Meta-Requirements-2.132.tar.gz',
         'FILES'        => q[cpan/CPAN-Meta-Requirements],
         'EXCLUDED'     => [
             qw(CONTRIBUTING.mkdn),
-            qw(t/00-compile.t),
             qw(t/00-report-prereqs.t),
             qw(t/00-report-prereqs.dd),
+            qw(t/version-cleanup.t),
             qr{^xt},
         ],
     },
@@ -321,14 +329,12 @@ use File::Glob qw(:case);
     },
 
     'Data::Dumper' => {
-        'DISTRIBUTION' => 'SMUELLER/Data-Dumper-2.151.tar.gz',
+        'DISTRIBUTION' => 'SMUELLER/Data-Dumper-2.154.tar.gz',
         'FILES'        => q[dist/Data-Dumper],
     },
 
     'DB_File' => {
-	# https://rt.cpan.org/Ticket/Display.html?id=96126
-	"CUSTOMIZED" => [ "DB_File.xs" ],
-        'DISTRIBUTION' => 'PMQS/DB_File-1.831.tar.gz',
+        'DISTRIBUTION' => 'PMQS/DB_File-1.835.tar.gz',
         'FILES'        => q[cpan/DB_File],
         'EXCLUDED'     => [
             qr{^patches/},
@@ -340,7 +346,7 @@ use File::Glob qw(:case);
     },
 
     'Devel::PPPort' => {
-        'DISTRIBUTION' => 'WOLFSAGE/Devel-PPPort-3.24.tar.gz',
+        'DISTRIBUTION' => 'WOLFSAGE/Devel-PPPort-3.28.tar.gz',
         # RJBS has asked MHX to have UPSTREAM be 'blead'
         # (i.e. move this from cpan/ to dist/)
         'FILES'        => q[cpan/Devel-PPPort],
@@ -363,15 +369,13 @@ use File::Glob qw(:case);
     },
 
     'Digest::MD5' => {
-        'DISTRIBUTION' => 'GAAS/Digest-MD5-2.53.tar.gz',
+        'DISTRIBUTION' => 'GAAS/Digest-MD5-2.54.tar.gz',
         'FILES'        => q[cpan/Digest-MD5],
         'EXCLUDED'     => ['rfc1321.txt'],
-        # Waiting to be merged upstream: see CPAN RT#89612
-        'CUSTOMIZED'   => ['t/files.t'],
     },
 
     'Digest::SHA' => {
-        'DISTRIBUTION' => 'MSHELOR/Digest-SHA-5.92.tar.gz',
+        'DISTRIBUTION' => 'MSHELOR/Digest-SHA-5.95.tar.gz',
         'FILES'        => q[cpan/Digest-SHA],
         'EXCLUDED'     => [
             qw( t/pod.t
@@ -388,8 +392,13 @@ use File::Glob qw(:case);
     },
 
     'Encode' => {
-        'DISTRIBUTION' => 'DANKOGAI/Encode-2.62.tar.gz',
+        'DISTRIBUTION' => 'DANKOGAI/Encode-2.70.tar.gz',
         'FILES'        => q[cpan/Encode],
+        'CUSTOMIZED'   => [
+            # Waiting to be merged upstream if it smokes ok: see CPAN RT#100347,
+            # in particular see khw's comments on that ticket on 21 Nov 2014.
+            qw( encoding.pm ),
+        ],
     },
 
     'encoding::warnings' => {
@@ -408,7 +417,7 @@ use File::Glob qw(:case);
     },
 
     'experimental' => {
-        'DISTRIBUTION' => 'LEONT/experimental-0.008.tar.gz',
+        'DISTRIBUTION' => 'LEONT/experimental-0.013.tar.gz',
         'FILES'        => q[cpan/experimental],
         'EXCLUDED'     => [
           qr{^t/release-.*\.t},
@@ -427,7 +436,7 @@ use File::Glob qw(:case);
     },
 
     'ExtUtils::CBuilder' => {
-        'DISTRIBUTION' => 'AMBS/ExtUtils/ExtUtils-CBuilder-0.280216.tar.gz',
+        'DISTRIBUTION' => 'AMBS/ExtUtils-CBuilder-0.280220.tar.gz',
         'FILES'        => q[dist/ExtUtils-CBuilder],
         'EXCLUDED'     => [
             qw(README.mkdn),
@@ -436,9 +445,9 @@ use File::Glob qw(:case);
     },
 
     'ExtUtils::Command' => {
-        'DISTRIBUTION' => 'FLORA/ExtUtils-Command-1.18.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/ExtUtils-Command-1.20.tar.gz',
         'FILES'        => q[cpan/ExtUtils-Command],
-        'EXCLUDED'     => [qr{^t/release-}],
+        'EXCLUDED'     => [qr{^xt/}],
     },
 
     'ExtUtils::Constant' => {
@@ -457,7 +466,7 @@ use File::Glob qw(:case);
     },
 
     'ExtUtils::Install' => {
-        'DISTRIBUTION' => 'BINGOS/ExtUtils-Install-1.68.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/ExtUtils-Install-2.04.tar.gz',
         'FILES'        => q[cpan/ExtUtils-Install],
         'EXCLUDED'     => [
             qw( t/lib/Test/Builder.pm
@@ -471,7 +480,7 @@ use File::Glob qw(:case);
     },
 
     'ExtUtils::MakeMaker' => {
-        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-6.98.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-7.04.tar.gz',
         'FILES'        => q[cpan/ExtUtils-MakeMaker],
         'EXCLUDED'     => [
             qr{^t/lib/Test/},
@@ -482,12 +491,17 @@ use File::Glob qw(:case);
             'PATCHING',
             'README.packaging',
         ],
+        # Applied upstream remove customisation when updating EUMM
+        'CUSTOMIZED'   => [ qw[ t/pm_to_blib.t ] ],
     },
 
     'ExtUtils::Manifest' => {
-        'DISTRIBUTION' => 'BINGOS/ExtUtils-Manifest-1.65.tar.gz',
+        'DISTRIBUTION' => 'ETHER/ExtUtils-Manifest-1.70.tar.gz',
         'FILES'        => q[cpan/ExtUtils-Manifest],
-        'EXCLUDED'     => [qr(^xt/)],
+        'EXCLUDED'     => [
+            qr(^t/00-report-prereqs),
+            qr(^xt/)
+        ],
     },
 
     'ExtUtils::ParseXS' => {
@@ -535,7 +549,7 @@ use File::Glob qw(:case);
     },
 
     'Filter::Util::Call' => {
-        'DISTRIBUTION' => 'RURBAN/Filter-1.49.tar.gz',
+        'DISTRIBUTION' => 'RURBAN/Filter-1.54.tar.gz',
         'FILES'        => q[cpan/Filter-Util-Call
                  pod/perlfilter.pod
                 ],
@@ -571,7 +585,7 @@ use File::Glob qw(:case);
     },
 
     'Getopt::Long' => {
-        'DISTRIBUTION' => 'JV/Getopt-Long-2.42.tar.gz',
+        'DISTRIBUTION' => 'JV/Getopt-Long-2.43.tar.gz',
         'FILES'        => q[cpan/Getopt-Long],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -583,7 +597,7 @@ use File::Glob qw(:case);
     },
 
     'HTTP::Tiny' => {
-        'DISTRIBUTION' => 'DAGOLDEN/HTTP-Tiny-0.047.tar.gz',
+        'DISTRIBUTION' => 'DAGOLDEN/HTTP-Tiny-0.054.tar.gz',
         'FILES'        => q[cpan/HTTP-Tiny],
         'EXCLUDED'     => [
             't/00-report-prereqs.t',
@@ -618,7 +632,7 @@ use File::Glob qw(:case);
     },
 
     'IO-Compress' => {
-        'DISTRIBUTION' => 'PMQS/IO-Compress-2.064.tar.gz',
+        'DISTRIBUTION' => 'PMQS/IO-Compress-2.068.tar.gz',
         'FILES'        => q[cpan/IO-Compress],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -630,7 +644,7 @@ use File::Glob qw(:case);
     },
 
     'IO::Socket::IP' => {
-        'DISTRIBUTION' => 'PEVANS/IO-Socket-IP-0.31.tar.gz',
+        'DISTRIBUTION' => 'PEVANS/IO-Socket-IP-0.36.tar.gz',
         'FILES'        => q[cpan/IO-Socket-IP],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -658,7 +672,7 @@ use File::Glob qw(:case);
     },
 
     'JSON::PP' => {
-        'DISTRIBUTION' => 'MAKAMAKA/JSON-PP-2.27203.tar.gz',
+        'DISTRIBUTION' => 'MAKAMAKA/JSON-PP-2.27300.tar.gz',
         'FILES'        => q[cpan/JSON-PP],
     },
 
@@ -673,18 +687,22 @@ use File::Glob qw(:case);
     },
 
     'libnet' => {
-        'DISTRIBUTION' => 'SHAY/libnet-1.27.tar.gz',
+        'DISTRIBUTION' => 'SHAY/libnet-3.05.tar.gz',
         'FILES'        => q[cpan/libnet],
         'EXCLUDED'     => [
             qw( Configure
-                install-nomake
+                t/changes.t
+                t/critic.t
+                t/pod.t
+                t/pod_coverage.t
                 ),
             qr(^demos/),
+            qr(^t/external/),
         ],
     },
 
     'Locale-Codes' => {
-        'DISTRIBUTION' => 'SBECK/Locale-Codes-3.31.tar.gz',
+        'DISTRIBUTION' => 'SBECK/Locale-Codes-3.33.tar.gz',
         'FILES'        => q[cpan/Locale-Codes],
         'EXCLUDED'     => [
             qw( README.first
@@ -699,7 +717,7 @@ use File::Glob qw(:case);
     },
 
     'Locale::Maketext' => {
-        'DISTRIBUTION' => 'TODDR/Locale-Maketext-1.25.tar.gz',
+        'DISTRIBUTION' => 'TODDR/Locale-Maketext-1.26.tar.gz',
         'FILES'        => q[dist/Locale-Maketext],
         'EXCLUDED'     => [
             qw(
@@ -782,13 +800,13 @@ use File::Glob qw(:case);
     },
 
     'MIME::Base64' => {
-        'DISTRIBUTION' => 'GAAS/MIME-Base64-3.14.tar.gz',
+        'DISTRIBUTION' => 'GAAS/MIME-Base64-3.15.tar.gz',
         'FILES'        => q[cpan/MIME-Base64],
         'EXCLUDED'     => ['t/bad-sv.t'],
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.021002.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20150214.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
@@ -798,7 +816,7 @@ use File::Glob qw(:case);
     },
 
     'Module::Load::Conditional' => {
-        'DISTRIBUTION' => 'BINGOS/Module-Load-Conditional-0.62.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-Load-Conditional-0.64.tar.gz',
         'FILES'        => q[cpan/Module-Load-Conditional],
     },
 
@@ -808,11 +826,12 @@ use File::Glob qw(:case);
     },
 
     'Module::Metadata' => {
-        'DISTRIBUTION' => 'ETHER/Module-Metadata-1.000024.tar.gz',
+        'DISTRIBUTION' => 'ETHER/Module-Metadata-1.000026.tar.gz',
         'FILES'        => q[cpan/Module-Metadata],
         'EXCLUDED'     => [
             qw(README.md),
             qw(t/00-report-prereqs.t),
+            qw(t/00-report-prereqs.dd),
             qr{^xt},
         ],
     },
@@ -821,7 +840,6 @@ use File::Glob qw(:case);
         'DISTRIBUTION' => 'SMPETERS/Net-Ping-2.41.tar.gz',
         'FILES'        => q[dist/Net-Ping],
         'EXCLUDED'     => [
-            qr{^.travis.yml},
             qr{^README.md},
         ],
     },
@@ -858,19 +876,18 @@ use File::Glob qw(:case);
     },
 
     'Perl::OSType' => {
-        'DISTRIBUTION' => 'DAGOLDEN/Perl-OSType-1.007.tar.gz',
+        'DISTRIBUTION' => 'DAGOLDEN/Perl-OSType-1.008.tar.gz',
         'FILES'        => q[cpan/Perl-OSType],
         'EXCLUDED'     => [qw(tidyall.ini), qr/^xt/, qr{^t/00-}],
     },
 
     'perlfaq' => {
-        'DISTRIBUTION' => 'LLAP/perlfaq-5.0150045.tar.gz',
+        'DISTRIBUTION' => 'ETHER/perlfaq-5.021009.tar.gz',
         'FILES'        => q[cpan/perlfaq],
         'EXCLUDED'     => [
-            qw( t/release-pod-syntax.t
-                t/release-eol.t
-                t/release-no-tabs.t
-                )
+            qw( inc/CreateQuestionList.pm
+                t/00-compile.t),
+            qr{^xt/},
         ],
     },
 
@@ -892,17 +909,17 @@ use File::Glob qw(:case);
     },
 
     'Pod::Escapes' => {
-        'DISTRIBUTION' => 'NEILB/Pod-Escapes-1.06.tar.gz',
+        'DISTRIBUTION' => 'NEILB/Pod-Escapes-1.07.tar.gz',
         'FILES'        => q[cpan/Pod-Escapes],
     },
 
     'Pod::Parser' => {
-        'DISTRIBUTION' => 'MAREKR/Pod-Parser-1.62.tar.gz',
+        'DISTRIBUTION' => 'MAREKR/Pod-Parser-1.63.tar.gz',
         'FILES'        => q[cpan/Pod-Parser],
     },
 
     'Pod::Perldoc' => {
-        'DISTRIBUTION' => 'MALLEN/Pod-Perldoc-3.23.tar.gz',
+        'DISTRIBUTION' => 'MALLEN/Pod-Perldoc-3.25.tar.gz',
         'FILES'        => q[cpan/Pod-Perldoc],
 
         # Note that we use the CPAN-provided Makefile.PL, since it
@@ -916,7 +933,7 @@ use File::Glob qw(:case);
     },
 
     'Pod::Simple' => {
-        'DISTRIBUTION' => 'DWHEELER/Pod-Simple-3.28.tar.gz',
+        'DISTRIBUTION' => 'DWHEELER/Pod-Simple-3.29.tar.gz',
         'FILES'        => q[cpan/Pod-Simple],
     },
 
@@ -954,7 +971,7 @@ use File::Glob qw(:case);
     },
 
     'Scalar-List-Utils' => {
-        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.39.tar.gz',
+        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.41.tar.gz',
         'FILES'    => q[cpan/Scalar-List-Utils],
     },
 
@@ -970,7 +987,7 @@ use File::Glob qw(:case);
     },
 
     'Socket' => {
-        'DISTRIBUTION' => 'PEVANS/Socket-2.014.tar.gz',
+        'DISTRIBUTION' => 'PEVANS/Socket-2.018.tar.gz',
         'FILES'        => q[cpan/Socket],
     },
 
@@ -1031,7 +1048,7 @@ use File::Glob qw(:case);
     },
 
     'Test::Harness' => {
-        'DISTRIBUTION' => 'LEONT/Test-Harness-3.32.tar.gz',
+        'DISTRIBUTION' => 'LEONT/Test-Harness-3.35.tar.gz',
         'FILES'        => q[cpan/Test-Harness],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1050,22 +1067,27 @@ use File::Glob qw(:case);
     },
 
     'Test::Simple' => {
-        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.001003.tar.gz',
+        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.301001_098.tar.gz',
         'FILES'        => q[cpan/Test-Simple],
         'EXCLUDED'     => [
             qr{^t/xt},
+            qr{^xt},
+            qr{^profiling},
             qw( .perlcriticrc
                 .perltidyrc
                 examples/indent.pl
                 examples/subtest.t
-                t/00compile.t
-                t/pod.t
-                t/pod-coverage.t
-                t/Builder/reset_outputs.t
-                lib/Test/Builder/IO/Scalar.pm
+                t/Legacy/00compile.t
+                t/Legacy/pod.t
+                t/xxx-changes_updated.t
+                t/zzz-check-breaks.t
+                t/Legacy/ribasushi_diag.t
                 ),
         ],
-    },
+       'CUSTOMIZED'   => [
+            # Waiting to be merged upstream: see pull request #494
+            qw( t/Legacy/exit.t ),
+        ],    },
 
     'Text::Abbrev' => {
         'DISTRIBUTION' => 'FLORA/Text-Abbrev-1.02.tar.gz',
@@ -1160,8 +1182,13 @@ use File::Glob qw(:case);
     },
 
     'threads' => {
-        'DISTRIBUTION' => 'JDHEDDEN/threads-1.92.tar.gz',
+        'DISTRIBUTION' => 'JDHEDDEN/threads-1.96.tar.gz',
         'FILES'        => q[dist/threads],
+        'CUSTOMIZED'   => [
+            # Waiting to be merged upstream: see CPAN RT#100755
+            qw( threads.xs
+                lib/threads.pm),
+        ],
         'EXCLUDED'     => [
             qr{^examples/},
             qw( t/pod.t
@@ -1207,12 +1234,12 @@ use File::Glob qw(:case);
     },
 
     'Time::Piece' => {
-        'DISTRIBUTION' => 'RJBS/Time-Piece-1.27.tar.gz',
+        'DISTRIBUTION' => 'RJBS/Time-Piece-1.29.tar.gz',
         'FILES'        => q[cpan/Time-Piece],
     },
 
     'Unicode::Collate' => {
-        'DISTRIBUTION' => 'SADAHIRO/Unicode-Collate-1.07.tar.gz',
+        'DISTRIBUTION' => 'SADAHIRO/Unicode-Collate-1.11.tar.gz',
         'FILES'        => q[cpan/Unicode-Collate],
         'EXCLUDED'     => [
             qr{N$},
@@ -1231,7 +1258,7 @@ use File::Glob qw(:case);
     },
 
     'version' => {
-        'DISTRIBUTION' => 'JPEACOCK/version-0.9908.tar.gz',
+        'DISTRIBUTION' => 'JPEACOCK/version-0.9909.tar.gz',
         'FILES'        => q[cpan/version vutil.c vutil.h vxs.inc],
         'EXCLUDED' => [
             qr{^vutil/lib/},
@@ -1250,7 +1277,6 @@ use File::Glob qw(:case);
 
             # Merged upstream, waiting for new CPAN release: see CPAN RT#92721
             qw( vutil.c
-                vxs.inc
                 ),
         ],
 
@@ -1271,16 +1297,15 @@ use File::Glob qw(:case);
     },
 
     'Win32' => {
-        'DISTRIBUTION' => "JDB/Win32-0.49.tar.gz",
+        'DISTRIBUTION' => "JDB/Win32-0.51.tar.gz",
         'FILES'        => q[cpan/Win32],
     },
 
     'Win32API::File' => {
-        'DISTRIBUTION' => 'CHORNY/Win32API-File-0.1201.tar.gz',
+        'DISTRIBUTION' => 'CHORNY/Win32API-File-0.1202.tar.gz',
         'FILES'        => q[cpan/Win32API-File],
         'EXCLUDED'     => [
             qr{^ex/},
-            't/pod.t',
         ],
     },
 
@@ -1351,7 +1376,8 @@ use File::Glob qw(:case);
                 ext/re/
                 lib/AnyDBM_File.{pm,t}
                 lib/Benchmark.{pm,t}
-                lib/B/Deparse{.pm,.t,-core.t}
+                lib/B/Deparse{.pm,.t,-*.t}
+                lib/B/Op_private.pm
                 lib/CORE.pod
                 lib/Class/Struct.{pm,t}
                 lib/Config.t
